wait_for_message

Function wait_for_message 

pub async fn wait_for_message<T: Clone + Send + Sync + 'static>(
    broker: &InMemoryBroker<T>,
    topic: &str,
    timeout: Duration,
) -> Message<T>
Wait until at least one message appears on topic or the timeout expires.

Returns the first message on the topic.

Panics

Panics if the timeout elapses before any message arrives.